[![CircleCI](https://circleci.com/gh/mmontagna/generic-encryptors/tree/master.svg?style=svg)](https://circleci.com/gh/mmontagna/generic-encryptors/tree/master) [![PyPI version](https://badge.fury.io/py/generic-encryptors.svg)](https://badge.fury.io/py/generic-encryptors)

# Generic encryptors

A set of encryptors which provide an interface compatible with https://github.com/mmontagna/generic-encoders
